import supabase
import sys


async def load_pyodide_modules():
    import micropip

    # ModuleNotFoundError: The module 'ssl' is unvendored from the Python standard library in the Pyodide distribution.
    # See https://pyodide.org/en/stable/usage/loading-packages.html for more details.
    await micropip.install("ssl")


if sys.platform == "emscripten":
    load_pyodide_modules()

__version__ = "0.1.4"


def Client():
    # TODO dont hard code this
    supabase_url: str = "https://api.humata.ai"
    supabase_anon_key: str = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpc3MiOiJzdXBhYmFzZSIsInJlZiI6ImJlbnpmb2RxdWF0amNheHFoYm1rIiwicm9sZSI6ImFub24iLCJpYXQiOjE2NzI0Mzg4MDYsImV4cCI6MTk4ODAxNDgwNn0.5YmrDS0ie09qbFdRBZpX9ygXQSi82F5g25tRk57OKT4"
    return supabase.create_client(supabase_url, supabase_anon_key)



import unittest
import humata


class TestSimple(unittest.TestCase):
    def test_version(self):
        self.assertTrue(isinstance(humata.__version__, str))


if __name__ == "__main__":
    unittest.main()



import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='humata',
    author='Humata',
    author_email='support@humata.ai',
    description='Humata.ai Python SDK',
    keywords='humata, humata.ai',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://www.humata.ai/',
    project_urls={
        'Documentation': 'https://www.humata.ai/',
        'Bug Reports': 'https://ww.humata.ai/'
    },
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    classifiers=[],
    python_requires='>=3.6',
    install_requires=[
        "supabase==2.3.1"
    ],
    extras_require={
        'dev': ['check-manifest'],
    },
)
